@@ -115,11 +115,11 @@ except ImportError:
 les diagrammes de Bode")
 
 """ historique des versions
-0.3.4 : 2022-01
+0.3.5 : 2022-01
 0.0.1 : initial release 2021-11
 """
 
-__version__ = (0, 3, 4)
+__version__ = (0, 3, 5)
 __author__ = "Fabrice Sincère <fabrice.sincere@ac-grenoble.fr>"
 
 
@@ -543,6 +543,7 @@ coeff_amortissement=0.16, w0=10000))
         else:
             # approximation (car la précision de la formule
             # théorique se dégrade quand m augmente)
+            # développement limité
             return w0/(2*math.pi)/math.sqrt(2*(2*m*m-1))
 
     @staticmethod
@@ -559,13 +560,24 @@ facteur_resonance_db=20))
         if facteur_resonance_db <= 0:
             raise ValueError("Valeur positive attendue")
 
-        # résolution à partir de la fonction inverse
-        def facteur_resonance(coeff_amortissement):
-            m = coeff_amortissement
-            f = 1/(2*m*math.sqrt(1-m*m))
-            return 20*math.log10(f)
+        if facteur_resonance_db > 1000:
+            # TODO :
+            # développement limité
+            return 0.0
 
-        return _rechercheSolution(1e-300, 2**-0.5, facteur_resonance_db, 1e-9, facteur_resonance)
+        # résolution à partir de la fonction inverse
+        # !calcul aberrant quand facteur_resonance_db > 1000 :
+        # on obtient 0.707 au lieu de 0!
+        # def facteur_resonance(coeff_amortissement):
+        #    m = coeff_amortissement
+        #    f = 1/(2*m*math.sqrt(1-m*m))
+        #    return 20*math.log10(f)
+        # return _rechercheSolution(1e-300, 2**-0.5, facteur_resonance_db, 1e-9,
+        # facteur_resonance)
+
+        # calcul exact
+        f = 10**(facteur_resonance_db/20)
+        return math.sqrt((1-math.sqrt(1-1/f**2))/2)
 
     @staticmethod
     def abaque_facteur_resonance_harmonique(coeff_amortissement: float) -> tuple:
@@ -724,7 +736,6 @@ entre 0 et 100 %")
                 # on élargie l'intervalle
                 while u(intervalle) < 1-p:
                     intervalle *= 2
-
             return _rechercheSolution(0, intervalle, 1-p, 1e-9, u)
 
         elif m > 1:
@@ -750,7 +761,6 @@ entre 0 et 100 %")
                 # on élargie l'intervalle
                 while u(intervalle) < 1-p:
                     intervalle *= 2
-
             return _rechercheSolution(0, intervalle, 1-p, 1e-9, u)
 
     @staticmethod
@@ -770,8 +780,11 @@ Exemple :
                 return 0
             else:
                 # résolution à partir de la fonction inverse
-                return _rechercheSolution(0, 1, depassement, 1e-9,
-                                          Ordre2.abaque_depassement)
+                # return _rechercheSolution(0, 1, depassement, 1e-9,
+                #                           Ordre2.abaque_depassement)
+
+                # solution exacte !
+                return -math.log(depassement/100)/math.sqrt(math.pi**2+math.log(depassement/100)**2)
         raise ValueError("Le premier dépassement doit être compris \
 entre 0 et 100 %")
 
@@ -788,7 +801,7 @@ Exemple :
         if 0 <= coeff_amortissement <= 1:
             if coeff_amortissement == 1:
                 return 0
-            # formule directe
+            # formule exacte
             D = math.exp(-n*coeff_amortissement*math.pi /
                          (math.sqrt(1-coeff_amortissement**2)))*100
             return D
@@ -1012,6 +1025,8 @@ Exemple :
 141.42135620...
 """
     # autre solution : module Scipy...
+    if (f(a)-y0)*(f(b)-y0) > 0:
+        raise ValueError("Problème de convergence")
     compteur = 0
     while ((abs(a-b) if a == 0 else abs((a-b)/a))) > abs(eps):
         c = (a+b)/2
@@ -1020,7 +1035,7 @@ Exemple :
         else:
             a = c
         compteur += 1
-        if compteur > 10000:
+        if compteur > 1000:
             raise ValueError("Problème de convergence")
     return c
 
